@@ -16,17 +16,25 @@
 #
 from samba import provision, param
 import os
+import random
 import shutil
+import subprocess
 from samba.tests import (env_loadparm, create_test_ou, BlackboxProcessError,
-                         BlackboxTestCase, connect_samdb)
+                         BlackboxTestCase, connect_samdb, delete_force)
+from samba.tests.gkdi import GkdiBaseTest
 import ldb
 from samba.samdb import SamDB
 from samba.auth import system_session
 from samba import Ldb, dn_from_dns_name
+from samba.netcmd import CommandError
 from samba.netcmd.fsmo import get_fsmo_roleowner
 import re
 from samba import sites
-from samba.dsdb import _dsdb_load_udv_v2
+from samba.dsdb import (
+    _dsdb_load_udv_v2,
+    DS_GUID_DOMAIN_CONTROLLERS_CONTAINER,
+)
+from samba import dsdb
 from samba import safe_tarfile as tarfile
 
 
@@ -38,6 +46,18 @@ def get_prim_dom(secrets_path, lp):
                               scope=ldb.SCOPE_SUBTREE,
                               expression="(objectClass=kerberosSecret)")
 
+# A set of attributes we know should be confidential.
+confidential_attrs = frozenset({
+    "msFVE-KeyPackage",
+    "msFVE-RecoveryPassword",
+    "msKds-RootKeyData",
+})
+
+
+def confidential_values_present(msg: ldb.Message) -> bool:
+    return any(map(msg.get, confidential_attrs))
+
+
 # The backup tests require that a completely clean LoadParm object gets used
 # for the restore. Otherwise the same global LP gets re-used, and the LP
 # settings can bleed from one test case to another.
@@ -45,7 +65,7 @@ def get_prim_dom(secrets_path, lp):
 # in a separate process (as opposed to runcmd(), runsubcmd()).
 # So although this is a samba-tool test, we don't inherit from SambaToolCmdTest
 # so that we never inadvertently use .runcmd() by accident.
-class DomainBackupBase(BlackboxTestCase):
+class DomainBackupBase(BlackboxTestCase, GkdiBaseTest):
 
     def setUp(self):
         super().setUp()
@@ -116,7 +136,7 @@ class DomainBackupBase(BlackboxTestCase):
         self.assertTrue(server_found,
                         "Could not find %s server" % expected_server)
 
-        if expected_count:
+        if expected_count is not None:
             self.assertTrue(len(res) == expected_count)
 
     def restore_dir(self):
@@ -131,13 +151,30 @@ class DomainBackupBase(BlackboxTestCase):
         extract_dir = self.restore_dir()
         with tarfile.open(backup_file) as tf:
             tf.extractall(extract_dir)
+        return extract_dir
 
-    def _test_backup_untar(self, primary_domain_secrets=0):
+    def _test_backup_untar(
+        self,
+        primary_domain_secrets=0,
+        verify_checksums=False
+    ):
         """Creates a backup, untars the raw files, and sanity-checks the DB"""
         backup_file = self.create_backup()
-        self.untar_backup(backup_file)
+        extract_dir = self.untar_backup(backup_file)
 
-        private_dir = os.path.join(self.restore_dir(), "private")
+        if (verify_checksums):
+            p = subprocess.Popen(
+                ["sha256sum", "-c", "SHA256SUM"],
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                cwd=extract_dir,
+            )
+            (out, err) = p.communicate()
+            if p.returncode:
+                print("Error: " + err.decode('utf-8'))
+                raise CommandError('Failed to verify checksums')
+
+        private_dir = os.path.join(extract_dir, "private")
         samdb_path = os.path.join(private_dir, "sam.ldb")
         lp = env_loadparm()
         samdb = SamDB(url=samdb_path, session_info=system_session(), lp=lp)
@@ -165,18 +202,130 @@ class DomainBackupBase(BlackboxTestCase):
         backup_file = self.create_backup()
         self.restore_backup(backup_file)
         lp = self.check_restored_smbconf()
-        self.check_restored_database(lp)
+        restored_samdb = self.check_restored_database(lp)
+
+        # Search across naming contexts to ensure we don’t miss any objects.
+        cross_ncs = ["search_options:1:2"]
+
+        # Search the entire restored database for GKDI root keys.
+        restored_root_keys = restored_samdb.search(
+            restored_samdb.get_root_basedn(),
+            expression="objectClass=msKds-ProvRootKey",
+            scope=ldb.SCOPE_SUBTREE,
+            attrs=list(confidential_attrs),
+            controls=cross_ncs,
+        )
+        # Assert that at least one key exists.
+        self.assertLess(0, len(restored_root_keys))
+
+        # Assert that the confidential material is still present.
+        for msg in restored_root_keys:
+            self.assertTrue(confidential_values_present(msg))
 
     def _test_backup_restore_no_secrets(self):
         """Does a backup/restore with secrets excluded from the resulting DB"""
 
+        samdb: SamDB = self.ldb
+
+        # Use the DC account as the parent of a new msFVE-RecoveryInformation object.
+        mach_dn = samdb.get_wellknown_dn(
+            samdb.get_default_basedn(), DS_GUID_DOMAIN_CONTROLLERS_CONTAINER
+        )
+        mach_dn.add_child(f"CN={self.server}")
+
+        # Get the machine account's GUID.
+        res = samdb.search(mach_dn, scope=ldb.SCOPE_BASE, attrs=["objectGUID"])
+        mach_guid = res[0].get("objectGUID", idx=0)
+
+        # Create a child msFVE-RecoveryInformation object with some confidential
+        # attributes.
+
+        recovery_dn = ldb.Dn(samdb, str(mach_dn))
+        recovery_dn.add_child(f"CN=recovery_info_{random.randint(0, 0xFFFF)}")
+
+        self.addCleanup(delete_force, samdb, recovery_dn)
+        samdb.add({
+            "dn": recovery_dn,
+            "objectClass": "msFVE-RecoveryInformation",
+            "msFVE-RecoveryGuid": mach_guid,
+            "msFVE-KeyPackage": b"secret key package",
+            "msFVE-RecoveryPassword": "Secret007",
+        })
+
+        def ldap_display_name(item: ldb.Message) -> str:
+            return item.get("lDAPDisplayName", idx=0).decode()
+
+        # Look up all the confidential attributes in the schema.
+        res = samdb.search(
+            samdb.get_schema_basedn(),
+            expression=(
+                f"(&(objectClass=attributeSchema)"
+                f"(searchFlags:{ldb.OID_COMPARATOR_AND}"
+                f":={dsdb.SEARCH_FLAG_CONFIDENTIAL}))"
+            ),
+            attrs=["lDAPDisplayName"],
+        )
+        all_confidential_attrs = set(map(ldap_display_name, res))
+
+        # Ensure that the attributes we think are confidential actually are.
+        self.assertLessEqual(confidential_attrs, all_confidential_attrs)
+
+        # Search for GKDI root keys containing secret material.
+        root_key_container_dn = self.get_root_key_container_dn(samdb)
+        root_keys = samdb.search(
+            root_key_container_dn,
+            scope=ldb.SCOPE_ONELEVEL,
+            attrs=list(confidential_attrs),
+        )
+        # Assert that at least one key exists.
+        self.assertLess(0, len(root_keys))
+
+        # Assert that the root keys all have confidential material.
+        for msg in root_keys:
+            self.assertTrue(confidential_values_present(msg))
+
+        # Assert that the recovery information object has confidential material.
+        recovery_info = samdb.search(
+            recovery_dn, scope=ldb.SCOPE_BASE, attrs=list(confidential_attrs)
+        )
+        self.assertTrue(confidential_values_present(recovery_info[0]))
+
+        # We don’t need the original samdb any more.
+        del samdb
+
         # exclude secrets when we create the backup
         backup_file = self.create_backup(extra_args=["--no-secrets"])
         self.restore_backup(backup_file)
         lp = self.check_restored_smbconf()
 
         # assert that we don't find user secrets in the DB
-        self.check_restored_database(lp, expect_secrets=False)
+        restored_samdb = self.check_restored_database(lp, expect_secrets=False)
+
+        # For the following searches, search across naming contexts to ensure we
+        # don’t miss any objects.
+        cross_ncs = ["search_options:1:2"]
+
+        # Search the entire restored database for GKDI root keys.
+        restored_root_keys = restored_samdb.search(
+            restored_samdb.get_root_basedn(),
+            expression="objectClass=msKds-ProvRootKey",
+            scope=ldb.SCOPE_SUBTREE,
+            attrs=list(confidential_attrs),
+            controls=cross_ncs,
+        )
+        # Assert that no keys exist.
+        self.assertEqual(0, len(restored_root_keys))
+
+        # Search the entire restored database for recovery info objects.
+        recovery_info_objs = restored_samdb.search(
+            restored_samdb.get_root_basedn(),
+            expression="objectClass=msFVE-RecoveryInformation",
+            scope=ldb.SCOPE_SUBTREE,
+            attrs=list(confidential_attrs),
+            controls=cross_ncs,
+        )
+        # Assert that no recovery info exists.
+        self.assertEqual(0, len(recovery_info_objs))
 
     def _test_backup_restore_into_site(self):
         """Does a backup and restores into a non-default site"""
@@ -336,10 +485,10 @@ class DomainBackupBase(BlackboxTestCase):
             self.assertRaises(KeyError, samdb.searchone, "unicodePwd", user_dn)
 
     def assert_secrets(self, samdb, expect_secrets):
-        """Check the user secrets in the restored DB match what's expected"""
+        """Check the secrets in the restored DB match what's expected"""
 
         # check secrets for the built-in testenv users match what's expected
-        test_users = ["alice", "bob", "jane"]
+        test_users = ["alice", "bob", "jane", "joe"]
         for user in test_users:
             self.assert_user_secrets(samdb, user, expect_secrets)
 
@@ -386,7 +535,7 @@ class DomainBackupBase(BlackboxTestCase):
             # that we skip the TestCaseInTempDir._remove_tempdir() assertions
             self.cleanup_tempdir()
             self.fail("Error calling samba-tool: %s" % e)
-        print(out)
+        print(out.decode())
 
     def create_backup(self, extra_args=None):
         """Runs the backup cmd to produce a backup file for the testenv DC"""
@@ -612,7 +761,7 @@ class DomainBackupOffline(DomainBackupBase):
         self.base_cmd = ["domain", "backup", "offline"]
 
     def test_backup_untar(self):
-        self._test_backup_untar(primary_domain_secrets=1)
+        self._test_backup_untar(primary_domain_secrets=1, verify_checksums=True)
 
     def test_backup_restore_with_conf(self):
         self._test_backup_restore_with_conf()
